@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::changes;
 
 our $DATE = '2016-03-12'; # DATE
-our $VERSION = '0.83'; # VERSION
+our $VERSION = '0.84'; # VERSION
 
 use 5.010;
 use strict;
@@ -15,7 +15,7 @@ our %SPEC;
 
 $SPEC{'handle_cmd'} = {
     v => 1.1,
-    summary => 'Show POD documentation of module/.pod/script',
+    summary => 'Show Changes of distribution/module',
     description => <<'_',
 
 This command will find a file named Changes/CHANGES/ChangeLog or other similar
@@ -52,14 +52,14 @@ sub handle_cmd {
     my $dbh = $state->{dbh};
 
     my $mod_or_dist = $args{module_or_dist};
-    $mod_or_dist =~ s!/!::!g;
+    $mod_or_dist =~ s!/!::!g; # XXX this should be done by coercer
 
     my @join;
     my @where;
     my @bind;
 
     if ($mod_or_dist =~ /-/) {
-        push @where, "file.id = (SELECT file_id FROM dist WHERE name=? LIMIT 1)";
+        push @where, "file.id = (SELECT file_id FROM dist WHERE name=? ORDER BY version_numified DESC LIMIT 1)";
         push @bind, $mod_or_dist;
     } else {
         push @where, "file.id = (SELECT file_id FROM module WHERE name=? LIMIT 1)";
@@ -78,10 +78,9 @@ ORDER BY content.path";
     my $sth = $dbh->prepare($sql);
     $sth->execute(@bind);
 
-    my $has_rows;
-    my $row;
-    while ($row = $sth->fetchrow_hashref) {
-        $has_rows++;
+    my $first_row;
+    while (my $row = $sth->fetchrow_hashref) {
+        $first_row //= $row;
         next unless $row->{content_path} =~ m!\A
                                               (?:[^/]+/)?
                                               (changes|changelog)
@@ -117,15 +116,15 @@ ORDER BY content.path";
         }];
     }
 
-    if ($has_rows) {
-        return [404, "No Changes file found in $row->{release}"];
+    if ($first_row) {
+        return [404, "No Changes file found in $first_row->{release}"];
     } else {
         return [404, "No such module or dist"];
     }
 }
 
 1;
-# ABSTRACT: Show POD documentation of module/.pod/script
+# ABSTRACT: Show Changes of distribution/module
 
 __END__
 
@@ -135,18 +134,18 @@ __END__
 
 =head1 NAME
 
-App::lcpan::Cmd::changes - Show POD documentation of module/.pod/script
+App::lcpan::Cmd::changes - Show Changes of distribution/module
 
 =head1 VERSION
 
-This document describes version 0.83 of App::lcpan::Cmd::changes (from Perl distribution App-lcpan), released on 2016-03-12.
+This document describes version 0.84 of App::lcpan::Cmd::changes (from Perl distribution App-lcpan), released on 2016-03-12.
 
 =head1 FUNCTIONS
 
 
 =head2 handle_cmd(%args) -> [status, msg, result, meta]
 
-Show POD documentation of module/.pod/script.
+Show Changes of distribution/module.
 
 Examples:
 
